@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+import time
 from opensign import OpenSign
 from opensign.canvas import OpenSignCanvas
 
@@ -12,9 +13,9 @@ def main():
     sign = OpenSign(chain=6)
     while True:
         sign.scroll_in_from_left(message)
-        sign.sleep(1)
+        time.sleep(1)
         sign.scroll_out_to_right(message)
-        sign.sleep(1)
+        time.sleep(1)
 
 
 # Main function
